@@ -16,7 +16,7 @@ class FlaskContextCreator(IQRContextCreator):
 
 
 class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
-    def __init__(self):
+    def __init__(self, default_err_code=500, default_err_msg='Internal server error'):
         FlaskContextCreator.__init__(self)
         QRLogger.__init__(self)
         self.app = None
@@ -24,6 +24,9 @@ class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
         self.methods = {}
         self.managers = dict()
 
+        self.default_err_code = default_err_code
+        self.default_err_msg = default_err_msg
+
     def init_server(self, config: IQRConfig):
         app_name = config['app_name']
         if app_name is None: app_name = 'app'
@@ -67,7 +70,7 @@ class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
         except Exception as e:
             super().info(in_msg)
             super().exception(e)
-            return 'Internal server error', 500
+            return self.default_err_msg, self.default_err_code
 
     def register_manager(self, manager: IQRManager):
         self.managers[manager.get_name()] = manager
